==> nextcloud-13.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/gallery/l10n/et_EE.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "Galerii",
    "There was a problem reading files from this album" : "Sellest albumist failide lugemisel tekkis probleem",
    "Aborting preview. Could not find the file" : "Eelvaate tühistamine. Faili ei leitud",
    "Could not move \"{file}\", target exists" : "Ei saanud faili \"{file}\", fail juba olemas",
    "Could not move \"{file}\"" : "\"{file}\" liigutamine ebaõnnestus",
    "No compatible server found at {remote}" : "Aadressil {remote} ei leitud ühilduvat serverit",
    "Invalid server url" : "Vigane serveri url",
    "Could not load the description" : "Kirjelduse laadimine ebaõnnestus",
    "Could not load the description: " : "Kirjelduse laadimine ebaõnnestus:",
    "Copyright" : "Autoriõigused",
    "Could not load the copyright notice: " : "Autoriõiguse info laadimine ebaõnnestus:",
    "Copyright notice" : "Autoriõiguste märge",
    "Link to copyright document" : "Link autoriõiguste dokumendile",
    "This application may not work properly on your browser." : "See rakendus ei pruugi sinu veebilehitsejas korralikult toimida.",
    "For an improved experience, please install one of the following alternatives" : "Parema kasutajakogemuse saamiseks paigalda palun üks järgnevatest alternatiividest",
    "Your browser is not supported!" : "Sinu veebilehitseja pole toetatud!",
    "please install one of the following alternatives" : "palun paigalda üks järgnevatest alternatiividest",
    "Album cannot be shown" : "Albumit ei saa näidata",
    "No media files found" : "Meediafaile ei leitud",
    "Upload pictures in the Files app to display them here" : "Lae rakenduses Failid polte üles, et neid siin näidata",
    "Upload new files via drag and drop or by using the [+] button above" : "Lae üles uusi faile lohistades või vajutades [+] nuppu ülal",
    "Configuration error" : "Seadistamise tõrge",
    "New" : "Uus",
    "Hide Album" : "Peida album",
    "Could not hide album" : "Albumit ei saanud peita",
    "Error loading slideshow template" : "Viga slaidiseansi kujunduse valimisel",
    "<strong>Error!</strong> Could not generate a preview of this file.<br>Please go to the next slide while we remove this image from the slideshow" : "<strong>Viga!</strong> Sellest failist ei saanud eelvaadet genereerida. <br>Palun minge järgmisele slaidile kuniks me selle pildi esitlusest eemaldame.",
    "Next" : "Järgmine",
    "Play" : "Esita",
    "Pause" : "Paus",
    "Previous" : "Eelmine",
    "Close" : "Sulge",
    "Download" : "Lae alla",
    "Toggle background" : "Tausta lülitamine",
    "Delete" : "Kustuta",
    "Share" : "Jaga",
    "Could not create file \"{file}\" because it already exists" : "Faili \"{file}\" loomine ebaõnnestus, sest see on juba olemas",
    "Could not create file \"{file}\"" : "Faili \"{file}\" loomine ebaõnnestus",
    "\"{name}\" is an invalid file name." : "\"{name}\" on vigane failinimi.",
    "File name cannot be empty." : "Faili nimi ei saa olla tühi.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" pole lubatud failitüüp",
    "Upload" : "Lae üles",
    "Error" : "Tõrge",
    "Error while sharing" : "Viga jagamisel",
    "Error while unsharing" : "Viga jagamise lõpetamisel",
    "Error while changing permissions" : "Viga õiguste muutmisel",
    "Shared with you and the group {group} by {owner}" : "Jagatud sinu ja {group} grupiga {owner} poolt",
    "Shared with you by {owner}" : "Sinuga jagas {owner}",
    "Share with users or groups …" : "Jaga kasutajate või gruppidega ...",
    "Share with users, groups or remote users …" : "Jaga kasutajate, gruppide või eemal olevate kasutajatega ...",
    "Share with people on other servers using their Federated Cloud ID username@example.com/cloud" : "Jaga inimestega teistes serverites kasutades nende liitpilve ID-d username@example.com/cloud",
    "Share link" : "Jaga linki",
    "The public link will expire no later than {days} days after it is created" : "Avalik link aegub mitte hiljem kui pärast {days} päeva selle loomist",
    "Link" : "Link",
    "Password protect" : "Parooliga kaitstud",
    "Password" : "Parool",
    "Choose a password for the public link" : "Vali avaliku lingi jaoks parool",
    "Allow editing" : "Luba muutmine",
    "Email link to person" : "Saada link isikule e-postiga",
    "Send" : "Saada",
    "Set expiration date" : "Määra aegumise kuupäev",
    "Expiration" : "Aegumine",
    "Expiration date" : "Aegumise kuupäev",
    "This list is maybe truncated - please refine your search term to see more results." : "See nimekiri võib olla kärbitud - palun täpsusta oma otsingut, et näha rohkem tulemusi.",
    "No users or groups found for {search}" : "Otsing {search} ei leidnud kasutajaid või gruppe",
    "No users found for {search}" : "Otsing {search} ei leidnud kasutajaid",
    "An error occured. Please try again" : "Tekkis tõrge. Palun proovi uuesti",
    "Adding user..." : "Kasutaja lisamine...",
    "group" : "grupp",
    "remote" : "kaug",
    "Resharing is not allowed" : "Edasijagamine pole lubatud",
    "Error while retrieving shares" : "Viga jagamiste laadimisel",
    "Unshare" : "Lõpeta jagamine",
    "notify by email" : "teavita e-postiga",
    "can share" : "saab jagada",
    "can edit" : "saab muuta",
    "access control" : "ligipääsukontroll",
    "create" : "loo",
    "change" : "muuda",
    "delete" : "kustuta",
    "Password protected" : "Parooliga kaitstud",
    "Error unsetting expiration date" : "Viga aegumise kuupäeva eemaldamisel",
    "Error setting expiration date" : "Viga aegumise kuupäeva määramisel",
    "Sending ..." : "Saatmine ...",
    "Email sent" : "E-kiri on saadetud",
    "Warning" : "Hoiatus",
    "This share is password-protected" : "See jagamine on parooliga kaitstud",
    "The password is wrong. Try again." : "Parool on vale. Proovi uuesti.",
    "Sort by name" : "Sorteeri nime järgi",
    "Sort by date" : "Sorteeri kuupäeva järgi",
    "Cancel upload" : "Tühista üleslaadimine",
    "Album information" : "Albumi info",
    "File list" : "Failide nimekiri",
    "Sorry, this file could not be found." : "Vabandust, seda faili ei leitud.",
    "Reasons might be:" : "Põhjused võivad olla:",
    "the wrong file ID was provided" : "sisestati vale faili ID",
    "the file was removed" : "fail on eemaldatud",
    "the file is corrupt" : "fail on vigane",
    "the encryption key is missing" : "krüpteerimisvõti puudub",
    "Here is the error message returned by the server: " : "Siin on viga, mille server tagastas:",
    "For more information, please contact your friendly Nextcloud administrator." : "Et saada rohkem infot võta ühendust oma Nextcloudi administraatoriga.",
    "Sorry, but the server could not fulfill your request." : "Vabandust, aga server ei suutnud sinu päringut täita.",
    "Possible reasons for the problem:" : "Probleemi võimalikud põhjused:",
    "a conflicting app was installed" : "paigaldati rakendus, mis tekitas konflikti",
    "a required component is missing or was disconnected" : "nõutud komponent puudub või pole ühendatud",
    "the filesystem is not readable" : "failisüsteem pole loetav",
    "Sorry, this link doesn't seem to work anymore." : "Vabandust, näib, et see link enam ei tööta.",
    "the item was removed" : "üksus on eemaldatud",
    "the link has expired" : "link on aegunud",
    "sharing is disabled" : "jagamine on peatatud",
    "For more information, please ask the person who has sent you this link." : "Küsi lisainfot inimeselt, kes sulle selle lingi saatis.",
    "Add to your Nextcloud" : "Lisa oma Nextcloudi",
    "Picture view" : "Pildi vaade",
    "Gallery view" : "Galeriivaade"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-13.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/gallery/l10n/et_EE.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "Galerii",
    "There was a problem reading files from this album" : "Sellest albumist failide lugemisel tekkis probleem",
    "Aborting preview. Could not find the file" : "Eelvaate tühistamine. Faili ei leitud",
    "Could not move \"{file}\", target exists" : "Ei saanud faili \"{file}\", fail juba olemas",
    "Could not move \"{file}\"" : "\"{file}\" liigutamine ebaõnnestus",
    "No compatible server found at {remote}" : "Aadressil {remote} ei leitud ühilduvat serverit",
    "Invalid server url" : "Vigane serveri url",
    "Could not load the description" : "Kirjelduse laadimine ebaõnnestus",
    "Could not load the description: " : "Kirjelduse laadimine ebaõnnestus:",
    "Copyright" : "Autoriõigused",
    "Could not load the copyright notice: " : "Autoriõiguse info laadimine ebaõnnestus:",
    "Copyright notice" : "Autoriõiguste märge",
    "Link to copyright document" : "Link autoriõiguste dokumendile",
    "This application may not work properly on your browser." : "See rakendus ei pruugi sinu veebilehitsejas korralikult toimida.",
    "For an improved experience, please install one of the following alternatives" : "Parema kasutajakogemuse saamiseks paigalda palun üks järgnevatest alternatiividest",
    "Your browser is not supported!" : "Sinu veebilehitseja pole toetatud!",
    "please install one of the following alternatives" : "palun paigalda üks järgnevatest alternatiividest",
    "Album cannot be shown" : "Albumit ei saa näidata",
    "No media files found" : "Meediafaile ei leitud",
    "Upload pictures in the Files app to display them here" : "Lae rakenduses Failid polte üles, et neid siin näidata",
    "Upload new files via drag and drop or by using the [+] button above" : "Lae üles uusi faile lohistades või vajutades [+] nuppu ülal",
    "Configuration error" : "Seadistamise tõrge",
    "New" : "Uus",
    "Hide Album" : "Peida album",
    "Could not hide album" : "Albumit ei saanud peita",
    "Error loading slideshow template" : "Viga slaidiseansi kujunduse valimisel",
    "<strong>Error!</strong> Could not generate a preview of this file.<br>Please go to the next slide while we remove this image from the slideshow" : "<strong>Viga!</strong> Sellest failist ei saanud eelvaadet genereerida. <br>Palun minge järgmisele slaidile kuniks me selle pildi esitlusest eemaldame.",
    "Next" : "Järgmine",
    "Play" : "Esita",
    "Pause" : "Paus",
    "Previous" : "Eelmine",
    "Close" : "Sulge",
    "Download" : "Lae alla",
    "Toggle background" : "Tausta lülitamine",
    "Delete" : "Kustuta",
    "Share" : "Jaga",
    "Could not create file \"{file}\" because it already exists" : "Faili \"{file}\" loomine ebaõnnestus, sest see on juba olemas",
    "Could not create file \"{file}\"" : "Faili \"{file}\" loomine ebaõnnestus",
    "\"{name}\" is an invalid file name." : "\"{name}\" on vigane failinimi.",
    "File name cannot be empty." : "Faili nimi ei saa olla tühi.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" pole lubatud failitüüp",
    "Upload" : "Lae üles",
    "Error" : "Tõrge",
    "Error while sharing" : "Viga jagamisel",
    "Error while unsharing" : "Viga jagamise lõpetamisel",
    "Error while changing permissions" : "Viga õiguste muutmisel",
    "Shared with you and the group {group} by {owner}" : "Jagatud sinu ja {group} grupiga {owner} poolt",
    "Shared with you by {owner}" : "Sinuga jagas {owner}",
    "Share with users or groups …" : "Jaga kasutajate või gruppidega ...",
    "Share with users, groups or remote users …" : "Jaga kasutajate, gruppide või eemal olevate kasutajatega ...",
    "Share link" : "Jaga linki",
    "The public link will expire no later than {days} days after it is created" : "Avalik link aegub mitte hiljem kui pärast {days} päeva selle loomist",
    "Link" : "Link",
    "Password protect" : "Parooliga kaitstud",
    "Password" : "Parool",
    "Choose a password for the public link" : "Vali avaliku lingi jaoks parool",
    "Allow editing" : "Luba muutmine",
    "Email link to person" : "Saada link isikule e-postiga",
    "Send" : "Saada",
    "Set expiration date" : "Määra aegumise kuupäev",
    "Expiration" : "Aegumine",
    "Expiration date" : "Aegumise kuupäev",
    "This list is maybe truncated - please refine your search term to see more results." : "See nimekiri võib olla kärbitud - palun täpsusta oma otsingut, et näha rohkem tulemusi.",
    "No users or groups found for {search}" : "Otsing {search} ei leidnud kasutajaid või gruppe",
    "No users found for {search}" : "Otsing {search} ei leidnud kasutajaid",
    "Adding user..." : "Kasutaja lisamine...",
    "group" : "grupp",
    "remote" : "kaug",
    "Resharing is not allowed" : "Edasijagamine pole lubatud",
    "Error while retrieving shares" : "Viga jagamiste laadimisel",
    "Unshare" : "Lõpeta jagamine",
    "notify by email" : "teavita e-postiga",
    "can share" : "saab jagada",
    "can edit" : "saab muuta",
    "access control" : "ligipääsukontroll",
    "create" : "loo",
    "change" : "muuda",
    "delete" : "kustuta",
    "Password protected" : "Parooliga kaitstud",
    "Error unsetting expiration date" : "Viga aegumise kuupäeva eemaldamisel",
    "Error setting expiration date" : "Viga aegumise kuupäeva määramisel",
    "Email sent" : "E-kiri on saadetud",
    "Warning" : "Hoiatus",
    "Add to your Nextcloud" : "Lisa oma Nextcloudi",
    "This share is password-protected" : "See jagamine on parooliga kaitstud",
    "The password is wrong. Try again." : "Parool on vale. Proovi uuesti.",
    "Sort by name" : "Sorteeri nime järgi",
    "Sort by date" : "Sorteeri kuupäeva järgi",
    "Cancel upload" : "Tühista üleslaadimine",
    "Album information" : "Albumi info",
    "File list" : "Failide nimekiri",
    "Sorry, this file could not be found." : "Vabandust, seda faili ei leitud.",
    "Reasons might be:" : "Põhjused võivad olla:",
    "the wrong file ID was provided" : "sisestati vale faili ID",
    "the file was removed" : "fail on eemaldatud",
    "the file is corrupt" : "fail on vigane",
    "the encryption key is missing" : "krüpteerimisvõti puudub",
    "Here is the error message returned by the server: " : "Siin on viga, mille server tagastas:",
    "For more information, please contact your friendly Nextcloud administrator." : "Et saada rohkem infot võta ühendust oma Nextcloudi administraatoriga.",
    "Sorry, but the server could not fulfill your request." : "Vabandust, aga server ei suutnud sinu päringut täita.",
    "Possible reasons for the problem:" : "Probleemi võimalikud põhjused:",
    "a conflicting app was installed" : "paigaldati rakendus, mis tekitas konflikti",
    "a required component is missing or was disconnected" : "nõutud komponent puudub või pole ühendatud",
    "the filesystem is not readable" : "failisüsteem pole loetav",
    "Sorry, this link doesn't seem to work anymore." : "Vabandust, näib, et see link enam ei tööta.",
    "the item was removed" : "üksus on eemaldatud",
    "the link has expired" : "link on aegunud",
    "sharing is disabled" : "jagamine on peatatud",
    "For more information, please ask the person who has sent you this link." : "Küsi lisainfot inimeselt, kes sulle selle lingi saatis.",
    "Picture view" : "Pildi vaade",
    "Gallery view" : "Galeriivaade",
    "Share with people on other servers using their Federated Cloud ID username@example.com/cloud" : "Jaga inimestega teistes serverites kasutades nende liitpilve ID-d username@example.com/cloud",
    "An error occured. Please try again" : "Tekkis tõrge. Palun proovi uuesti",
    "Sending ..." : "Saatmine ..."
},
"nplurals=2; plural=(n != 1);");
